pub struct ClusterBootstrapInitdbPostInitSqlRefs {
pub config_map_refs: Option<Vec<ClusterBootstrapInitdbPostInitSqlRefsConfigMapRefs>>,
pub secret_refs: Option<Vec<ClusterBootstrapInitdbPostInitSqlRefsSecretRefs>>,
}Expand description
List of references to ConfigMaps or Secrets containing SQL files
to be executed as a superuser in the postgres database right after
the cluster has been created. The references are processed in a specific order:
first, all Secrets are processed, followed by all ConfigMaps.
Within each group, the processing order follows the sequence specified
in their respective arrays.
(by default empty)
Fields
config_map_refs: Option<Vec<ClusterBootstrapInitdbPostInitSqlRefsConfigMapRefs>>ConfigMapRefs holds a list of references to ConfigMaps
secret_refs: Option<Vec<ClusterBootstrapInitdbPostInitSqlRefsSecretRefs>>SecretRefs holds a list of references to Secrets