ClusterWalStoragePvcTemplateDataSource

Struct ClusterWalStoragePvcTemplateDataSource 

pub struct ClusterWalStoragePvcTemplateDataSource {
    pub api_group: Option<String>,
    pub kind: String,
    pub name: String,
}
dataSource field can be used to specify either:

  • An existing VolumeSnapshot object (snapshot.storage.k8s.io/VolumeSnapshot)
  • An existing PVC (PersistentVolumeClaim) If the provisioner or an external controller can support the specified data source, it will create a new volume based on the contents of the specified data source. When the AnyVolumeDataSource feature gate is enabled, dataSource contents will be copied to dataSourceRef, and dataSourceRef contents will be copied to dataSource when dataSourceRef.namespace is not specified. If the namespace is specified, then dataSourceRef will not be copied to dataSource.

Fields

api_group: Option<String>

APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required.

kind: String

Kind is the type of resource being referenced

name: String

Name is the name of resource being referenced